==> seedsui-react-2.5.5.tgz: package/es/Titlebar/Titlebar.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Device from './../Device';
import Bridge from './../Bridge';

var Titlebar = (_temp = _class = function (_Component) {
  _inherits(Titlebar, _Component);

  function Titlebar(props) {
    _classCallCheck(this, Titlebar);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.onClickBack = function () {
      var onClickBack = _this.props.onClickBack;
      // 如果有onClickBack的props,则优先执行props的方法

      if (onClickBack) {
        onClickBack();
        return;
      }
      // 否则走默认的返回
      Bridge.back();
    };

    _this.getButtonsDOM = function (arr) {
      return arr.map(function (item, index) {
        if (item === '$back') {
          item = {
            className: _this.props.backClassName || null,
            style: _this.props.backStyle || null,
            icon: _this.props.backIcon || null,
            iconClassName: _this.props.backIconClassName || null,
            iconStyle: _this.props.backIconStyle || {},
            caption: _this.props.backCaption || null,
            onClick: _this.onClickBack
          };
        }
        return React.createElement(
          'a',
          { key: index, disabled: item.disabled, onClick: function onClick(e) {
              if (item.onClick) item.onClick(Object.getArgs(e, item.args));
            }, className: 'titlebar-button button' + (item.className ? ' ' + item.className : ' bar'), style: item.style },
          (item.iconSrc || item.iconClassName) && React.createElement('span', { className: 'icon' + (item.iconClassName ? ' ' + item.iconClassName : ''), style: Object.assign(item.iconSrc ? { backgroundImage: 'url(' + item.iconSrc + ')' } : {}, item.iconStyle) }),
          item.icon && item.icon,
          item.caption && React.createElement(
            'span',
            null,
            item.caption
          )
        );
      });
    };

    _this.state = {};
    return _this;
  }

  Titlebar.prototype.render = function render() {
    var _props = this.props,
        className = _props.className,
        showUrlTitle = _props.showUrlTitle,
        caption = _props.caption,
        captionClassName = _props.captionClassName,
        captionStyle = _props.captionStyle,
        children = _props.children,
        onClickCaption = _props.onClickCaption,
        lButtons = _props.lButtons,
        rButtons = _props.rButtons,
        backIconClassName = _props.backIconClassName,
        backIconStyle = _props.backIconStyle,
        backClassName = _props.backClassName,
        backStyle = _props.backStyle,
        backCaption = _props.backCaption,
        onClickBack = _props.onClickBack,
        others = _objectWithoutProperties(_props, ['className', 'showUrlTitle', 'caption', 'captionClassName', 'captionStyle', 'children', 'onClickCaption', 'lButtons', 'rButtons', 'backIconClassName', 'backIconStyle', 'backClassName', 'backStyle', 'backCaption', 'onClickBack']);

    var lButtonsDOM = null;
    if (Array.isArray(lButtons)) {
      lButtonsDOM = this.getButtonsDOM(lButtons);
    }
    var rButtonsDOM = null;
    if (Array.isArray(rButtons)) {
      rButtonsDOM = this.getButtonsDOM(rButtons);
    }
    // 设置显示标题
    var title = Device.getUrlParameter('titlebar', location.search);
    if (showUrlTitle && title) {
      caption = React.createElement(
        'h1',
        { className: 'titlebar-caption nowrap text-center' + (captionClassName ? ' ' + captionClassName : ''), style: captionStyle, onClick: onClickCaption },
        decodeURIComponent(title)
      );
    } else if (typeof caption === 'string') {
      caption = React.createElement(
        'h1',
        { className: 'titlebar-caption nowrap text-center' + (captionClassName ? ' ' + captionClassName : ''), style: captionStyle, onClick: onClickCaption },
        caption
      );
    }
    return React.createElement(
      'div',
      _extends({ className: 'titlebar' + (className ? ' ' + className : '') }, others),
      React.createElement(
        'div',
        { className: 'titlebar-left' },
        lButtonsDOM
      ),
      caption,
      children,
      React.createElement(
        'div',
        { className: 'titlebar-right' },
        rButtonsDOM
      )
    );
  };

  return Titlebar;
}(Component), _class.defaultProps = {
  showUrlTitle: true,
  lButtons: ['$back'],
  className: 'border-b',
  backIconClassName: 'shape-arrow-left'
}, _temp);
export { Titlebar as default };
Titlebar.propTypes = process.env.NODE_ENV !== "production" ? {
  className: PropTypes.string,

  showUrlTitle: PropTypes.bool, // 标题是否显示url中的titlebar
  caption: PropTypes.node,
  // 以下三个属性, 只有caption为string类型或者显示地址栏标题时才有用
  captionClassName: PropTypes.string,
  captionStyle: PropTypes.object,
  onClickCaption: PropTypes.func,

  lButtons: PropTypes.array, // [{className: string, style: object, iconClassName: string, icon: node, caption: string}]
  rButtons: PropTypes.array,
  backClassName: PropTypes.string,
  backStyle: PropTypes.object,
  backIcon: PropTypes.node,
  backIconClassName: PropTypes.string,
  backIconStyle: PropTypes.object,
  backCaption: PropTypes.string,
  onClickBack: PropTypes.func,
  children: PropTypes.node
} : {};

==> seedsui-react-2.6.2.tgz: package/es/Titlebar/Titlebar.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Device from './../Device';
import Bridge from './../Bridge';

var Titlebar = (_temp = _class = function (_Component) {
  _inherits(Titlebar, _Component);

  function Titlebar(props) {
    _classCallCheck(this, Titlebar);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.onClickBack = function () {
      var onClickBack = _this.props.onClickBack;
      // 如果有onClickBack的props,则优先执行props的方法

      if (onClickBack) {
        onClickBack();
        return;
      }
      // 否则走默认的返回
      Bridge.back();
    };

    _this.getButtonsDOM = function (arr) {
      return arr.map(function (item, index) {
        if (item === '$back') {
          item = {
            className: _this.props.backClassName || null,
            style: _this.props.backStyle || null,
            icon: _this.props.backIcon || null,
            iconClassName: _this.props.backIconClassName || null,
            iconStyle: _this.props.backIconStyle || {},
            caption: _this.props.backCaption || null,
            onClick: _this.onClickBack
          };
        }
        return React.createElement(
          'a',
          { key: index, disabled: item.disabled, onClick: function onClick(e) {
              if (item.onClick) item.onClick(Object.getArgs(e, item.args));
            }, className: 'titlebar-button button' + (item.className ? ' ' + item.className : ' bar'), style: item.style },
          (item.iconSrc || item.iconClassName) && React.createElement('span', { className: 'icon' + (item.iconClassName ? ' ' + item.iconClassName : ''), style: Object.assign(item.iconSrc ? { backgroundImage: 'url(' + item.iconSrc + ')' } : {}, item.iconStyle) }),
          item.icon && item.icon,
          item.caption && React.createElement(
            'span',
            null,
            item.caption
          )
        );
      });
    };

    _this.state = {};
    return _this;
  }

  Titlebar.prototype.render = function render() {
    var _props = this.props,
        className = _props.className,
        showUrlTitle = _props.showUrlTitle,
        caption = _props.caption,
        captionClassName = _props.captionClassName,
        captionStyle = _props.captionStyle,
        children = _props.children,
        onClickCaption = _props.onClickCaption,
        lButtons = _props.lButtons,
        rButtons = _props.rButtons,
        backIconClassName = _props.backIconClassName,
        backIconStyle = _props.backIconStyle,
        backClassName = _props.backClassName,
        backStyle = _props.backStyle,
        backCaption = _props.backCaption,
        onClickBack = _props.onClickBack,
        others = _objectWithoutProperties(_props, ['className', 'showUrlTitle', 'caption', 'captionClassName', 'captionStyle', 'children', 'onClickCaption', 'lButtons', 'rButtons', 'backIconClassName', 'backIconStyle', 'backClassName', 'backStyle', 'backCaption', 'onClickBack']);

    var lButtonsDOM = null;
    if (Array.isArray(lButtons)) {
      lButtonsDOM = this.getButtonsDOM(lButtons);
    }
    var rButtonsDOM = null;
    if (Array.isArray(rButtons)) {
      rButtonsDOM = this.getButtonsDOM(rButtons);
    }
    // 设置显示标题
    var title = Device.getUrlParameter('titlebar', location.search);
    if (showUrlTitle && title) {
      caption = React.createElement(
        'h1',
        { className: 'titlebar-caption nowrap text-center' + (captionClassName ? ' ' + captionClassName : ''), style: captionStyle, onClick: onClickCaption },
        decodeURIComponent(decodeURIComponent(title))
      );
    } else if (typeof caption === 'string') {
      caption = React.createElement(
        'h1',
        { className: 'titlebar-caption nowrap text-center' + (captionClassName ? ' ' + captionClassName : ''), style: captionStyle, onClick: onClickCaption },
        caption
      );
    }
    return React.createElement(
      'div',
      _extends({ className: 'titlebar' + (className ? ' ' + className : '') }, others),
      React.createElement(
        'div',
        { className: 'titlebar-left' },
        lButtonsDOM
      ),
      caption,
      children,
      React.createElement(
        'div',
        { className: 'titlebar-right' },
        rButtonsDOM
      )
    );
  };

  return Titlebar;
}(Component), _class.defaultProps = {
  showUrlTitle: true,
  lButtons: ['$back'],
  className: 'border-b',
  backIconClassName: 'shape-arrow-left'
}, _temp);
export { Titlebar as default };
Titlebar.propTypes = process.env.NODE_ENV !== "production" ? {
  className: PropTypes.string,

  showUrlTitle: PropTypes.bool, // 标题是否显示url中的titlebar
  caption: PropTypes.node,
  // 以下三个属性, 只有caption为string类型或者显示地址栏标题时才有用
  captionClassName: PropTypes.string,
  captionStyle: PropTypes.object,
  onClickCaption: PropTypes.func,

  lButtons: PropTypes.array, // [{className: string, style: object, iconClassName: string, icon: node, caption: string}]
  rButtons: PropTypes.array,
  backClassName: PropTypes.string,
  backStyle: PropTypes.object,
  backIcon: PropTypes.node,
  backIconClassName: PropTypes.string,
  backIconStyle: PropTypes.object,
  backCaption: PropTypes.string,
  onClickBack: PropTypes.func,
  children: PropTypes.node
} : {};
